import sys
import typing


def copy():
    ''' Copy the material settings and nodes

    '''

    pass


def new():
    ''' Add a new material

    '''

    pass


def paste():
    ''' Paste the material settings and nodes

    '''

    pass


def sss_preset_add(name: str = "", remove_active: bool = False):
    ''' Add or remove a Subsurface Scattering Preset

    :param name: Name, Name of the preset, used to make the path name
    :type name: str
    :param remove_active: remove_active
    :type remove_active: bool
    '''

    pass
