import sys
import typing


class RestrictBlend:
    context = None
    ''' '''

    data = None
    ''' '''


class _RestrictContext:
    user_preferences = None
    ''' '''

    window_manager = None
    ''' '''


class _RestrictData:
    pass
